# Define pkgdocdir for releases that don't define it already
%{!?_pkgdocdir: %global _pkgdocdir %{_docdir}/%{name}-%{version}}

%global proton_minimum_version 0.6

Name:          qpid-dispatch
Version:       0.2
Release:       7%{?dist}
Summary:       Dispatch router for Qpid
License:       ASL 2.0
URL:           http://qpid.apache.org/
Source0:       http://www.apache.org/dist/qpid/dispatch/%{version}/qpid-dispatch-%{version}.tar.gz

Patch01: 0001-NO-JIRA-Systemd-control-file-for-qdrouterd.patch
Patch02: 0002-NO-JIRA-SysVInit-script-for-qpid-dxrouterd.patch

BuildRequires: qpid-proton-c-devel >= %{proton_minimum_version}
BuildRequires: python-devel
BuildRequires: cmake
%{?fedora:BuildRequires: systemd}

Requires:      qpid-proton-c%{?_isa} >= %{proton_minimum_version}
Requires:      python
Requires:      python-qpid-proton >= %{proton_minimum_version}


%description
A lightweight message router, written in C and built on Qpid Proton, that provides flexible and scalable interconnect between AMQP endpoints or between endpoints and brokers.



%package -n libqpid-dispatch
Summary:  The Qpid Dispatch Router library
Requires: qpid-proton-c%{?_isa} >= %{proton_minimum_version}

%description -n libqpid-dispatch
%{summary}.


%files -n libqpid-dispatch
%{_libdir}/libqpid-dispatch.so.*
%{_exec_prefix}/lib/qpid-dispatch


%post -n libqpid-dispatch
/sbin/ldconfig

%postun -n libqpid-dispatch
/sbin/ldconfig




%package -n libqpid-dispatch-devel
Summary:  Development files for Qpid Dispatch
Requires: qpid-proton-c-devel >= %{proton_minimum_version}
Requires: libqpid-dispatch%{?_isa} = %{version}-%{release}


%description -n libqpid-dispatch-devel
%{summary}.


%files -n libqpid-dispatch-devel
%{_includedir}/qpid/dispatch.h
%{_includedir}/qpid/dispatch
%{_libdir}/libqpid-dispatch.so




%package router
Summary:  The Qpid Dispatch Router executable
Requires: libqpid-dispatch%{?_isa} = %{version}


%if 0%{?fedora}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
%endif

%description router
%{summary}.


%files router
%{_sbindir}/qdrouterd
%config(noreplace) %{_sysconfdir}/qpid-dispatch/qdrouterd.conf

%if 0%{?fedora}
%{_unitdir}/qdrouterd.service
%endif

%if 0%{?rhel}
%{_initrddir}/qpid-dxrouterd
%endif

%{_mandir}/man5/qdrouterd.conf.5*
%{_mandir}/man8/qdrouterd.8*


%pre router
getent group qpidd >/dev/null || groupadd -r qpidd
getent passwd qpidd >/dev/null || \
  useradd -r -M -g qpidd -d %{_localstatedir}/lib/qpidd -s /sbin/nologin \
    -c "Owner of Qpidd Daemons" qpidd
exit 0

# define the daemon processes properly for each operating system

# =======
# systemd
# =======

%if 0%{?fedora}

%post router
%systemd_post qpid-dxrouterd.service

%preun router
%systemd_preun qpid-dxrouterd.service

%postun router
%systemd_postun_with_restart qpid-dxrouterd.service

%endif

# ========
# sysvinit
# ========

%if 0%{?rhel}

%post router
/sbin/chkconfig --add qpid-dxrouterd

%preun router
if [ $1 -eq 0 ]; then
    /sbin/service qpid-dxrouterd stop >/dev/null 2>&1
    /sbin/chkconfig --del qpid-dxrouterd
fi

%postun router
if [ "$1" -ge "1" ]; then
    /sbin/service qpid-dxrouterd confrestart >/dev/null 2>&1
fi

%endif



%package router-docs
Summary:   Documentation for the Qpid Dispatch router
BuildArch: noarch


%description router-docs
%{summary}.


%files router-docs
%doc %{_pkgdocdir}



%package tools
Summary: Tools for the Qpid Dispatch router
Requires: python-qpid-proton
Requires: libqpid-dispatch%{?_isa} = %{version}


%description tools
%{summary}.


%files tools
%{_bindir}/qdstat
%{_bindir}/qdtest
%{_mandir}/man8/qdstat.8*

# ==================
# prep/build/install
# ==================

%prep
%setup -q

# ======================
# daemon startup patches
# ======================
%if 0%{?fedora}
%patch01 -p1
%endif

%if 0%{?rhel}
%patch02 -p1
%endif

%build
%cmake -DDOC_INSTALL_DIR=%{?_pkgdocdir} \
       -DCMAKE_BUILD_TYPE=RelWithDebInfo \
       .


%install
%make_install

# ============================
# install daemon control files
# ============================

%if 0%{?fedora}
mkdir -p %{buildroot}/%{_unitdir}
install -pm 644 %{_builddir}/qpid-dispatch-%{version}/etc/qdrouterd.service \
                %{buildroot}/%{_unitdir}
%endif

%if 0%{?rhel}
mkdir -p %{buildroot}/%{_initrddir}
install -pm 644 %{_builddir}/qpid-dispatch-%{version}/etc/qpid-dxrouterd \
                %{buildroot}/%{_initrddir}
%endif

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%changelog
* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Jul  9 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-6
- Removed intro-package comments which can cause POSTUN warnings.
- Added dependency on libqpid-dispatch from qpid-dispatch-tools.

* Wed Jul  2 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-5
- Fixed the path for the configuration file.
- Resolves: BZ#1115416

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 30 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-3
- Fixed build type to be RelWithDebInfo

* Tue Apr 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-2
- Fixed merging problems across Fedora and EPEL releases.

* Tue Apr 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.2-1
- Rebased on Qpid Dispatch 0.2.

* Wed Feb  5 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-4
- Fixed path to configuration in qpid-dispatch.service file.
- Added requires from qpid-dispatch-tools to python-qpid-proton.

* Thu Jan 30 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-3
- Fix build system to not discard CFLAGS provided by Fedora
- Resolves: BZ#1058448
- Simplified the specfile to be used across release targets.

* Fri Jan 24 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-2
- First release for Fedora.
- Resolves: BZ#1055721

* Thu Jan 23 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1.2
- Put all subpackage sections above prep/build/install.
- Removed check and clean sections.
- Added remaining systemd macros.
- Made qpid-dispatch-router-docs a noarch package.


* Wed Jan 22 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1.1
- Added the systemd macros for post/preun/postun
- Moved prep/build/install/check/clean above package definitions.

* Mon Jan 20 2014 Darryl L. Pierce <dpierce@redhat.com> - 0.1-1
- Initial packaging of the codebase.
